﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Microsoft.Xna.Framework.Input.Touch;
using System.Windows.Navigation;

namespace PhoneApp2
{
    public partial class MainPage : PhoneApplicationPage
    {

        private CompositeTransform compositeTransform = new CompositeTransform();

        private Brush startBgColor;
        private Brush bgColor = new SolidColorBrush(Colors.Orange);

        //触碰初始被触碰控件本身平移量
        double startX;
        double startY;

        //初次触碰点相对于被拖动控件基准点的坐标
        double firstTranslateX;
        double firstTranslateY;

        public MainPage()
        {
            InitializeComponent();

            rectangle.RenderTransform = compositeTransform;

            //设置可识别的手势，必须设置才能被启用
            TouchPanel.EnabledGestures = GestureType.Hold | GestureType.Tap | GestureType.DoubleTap | GestureType.Flick | GestureType.Pinch;

            //触控开始时发生
            rectangle.ManipulationStarted += new EventHandler<ManipulationStartedEventArgs>(Rectangle_ManipulationStarted);
            //触控过程中位置变更时发生
            rectangle.ManipulationDelta += new EventHandler<ManipulationDeltaEventArgs>(Rectangle_ManipulationDelta);
            //触控结束时发生
            rectangle.ManipulationCompleted += new EventHandler<ManipulationCompletedEventArgs>(Rectangle_ManipulationCompleted);

        }
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            //获取设备对触控的支持性
            var a = TouchPanel.GetCapabilities();
            if (a.IsConnected)
            {
                CapabilitiesText.Text = "当前设备支持" + a.MaximumTouchCount + "点触控";
            }
            base.OnNavigatedTo(e);
        }

        void Rectangle_ManipulationStarted(object sender, ManipulationStartedEventArgs e)
        {
            startBgColor = rectangle.Fill;
            (e.ManipulationContainer as Rectangle).Fill = bgColor;
            //这两个值效果一样，都是指被触控控件本身
            //(e.OriginalSource as Rectangle).Fill = endBgColor;

            //触碰初始被触碰控件本身平移量
            startX = compositeTransform.TranslateX;
            startY = compositeTransform.TranslateY;

            //初次触碰点相对于被拖动控件基准点的坐标
            firstTranslateX = e.ManipulationOrigin.X;
            firstTranslateY = e.ManipulationOrigin.Y;
        }

        void Rectangle_ManipulationDelta(object sender, ManipulationDeltaEventArgs e)
        {

            //当前触碰点相对于被拖动控件基准点的坐标
            ox.Text = e.ManipulationOrigin.X.ToString();
            oy.Text = e.ManipulationOrigin.Y.ToString();

            //当前触碰点相对于上一触碰点的坐标偏移
            dx.Text = e.DeltaManipulation.Translation.X.ToString();
            dy.Text = e.DeltaManipulation.Translation.Y.ToString();

            //当前触碰点相对于初次触碰点的坐标偏移
            tx.Text = e.CumulativeManipulation.Translation.X.ToString();
            ty.Text = e.CumulativeManipulation.Translation.Y.ToString();

            //控件跟随移动
            //compositeTransform.TranslateX += e.DeltaManipulation.Translation.X;
            //compositeTransform.TranslateY += e.DeltaManipulation.Translation.Y;
            //实时精准定位移动，不考虑连贯性
            compositeTransform.TranslateX += e.DeltaManipulation.Translation.X + e.ManipulationOrigin.X - firstTranslateX;
            compositeTransform.TranslateY += e.DeltaManipulation.Translation.Y + e.ManipulationOrigin.Y - firstTranslateY;


            //相对于上次的缩放量
            if (e.DeltaManipulation.Scale.X > 0 && e.DeltaManipulation.Scale.Y > 0)
            {
                compositeTransform.ScaleX *= e.DeltaManipulation.Scale.X;
                compositeTransform.ScaleY *= e.DeltaManipulation.Scale.Y;
            }

            //if (e.PinchManipulation != null)
            //{
            //    var a = e.PinchManipulation.Original.PrimaryContact.ToString() + "|" + e.PinchManipulation.Original.SecondaryContact.ToString();
            //    var b = e.PinchManipulation.Current.PrimaryContact.ToString() + "|" + e.PinchManipulation.Current.SecondaryContact.ToString();
            //    var c = e.PinchManipulation.CumulativeScale;
            //    var d = e.PinchManipulation.DeltaScale;
            //}


            //获取多个触控点的绝对坐标（相对于屏幕）和状态
            TouchCollection touchCollection = TouchPanel.GetState();
            string stateString = string.Empty;
            foreach (var item in touchCollection)
            {
                stateString += " " + item.Position.ToString() + "[" + item.State.ToString() + "]";
            }
            TouchCollectionText.Text = stateString;

        }

        void Rectangle_ManipulationCompleted(object sender, ManipulationCompletedEventArgs e)
        {
            rectangle.Fill = startBgColor;

            while (TouchPanel.IsGestureAvailable)
            {
                //p.Text = TouchPanel.GetCapabilities().MaximumTouchCount.ToString();
                //break;
                GestureSample gesture = TouchPanel.ReadGesture();
                p.Text = gesture.GestureType.ToString();
            }
        }

    }
}